require 'base64'
require 'signed/version'
require 'signed/signature'
require 'signed/utils'

# module for signing string
#
# can create and verify signature with expiry
module Signed
  module_function

  # signature format is signature("#{data}:#{expiry}:#{secret}"):base64(secondary)
  def create_signature(data, secret, expiry: nil, algo: 'SHA256')
    expiry = 'infinit' unless expiry
    signature = Signature.sign_with(algo, "#{data}:#{expiry}:#{secret}")

    "#{signature}:#{Base64.encode64(expiry.to_s)}"
  end

  def verify_signature(data, signature, secret, algo: 'SHA256')
    sign = signature.split(':')
    return false if sign.count < 2
    hash = sign[0]
    expiry = Base64.decode64(sign[1])
    return false if Utils.check_expiry(expiry)
    Signature.verify_hash(algo, hash, "#{data}:#{expiry}:#{secret}")
  end

  class << self
    alias_method :verify?, :verify_signature
    alias_method :sign, :create_signature
  end
end
